@@ -55,7 +55,7 @@ use Params::Classify 0.000 qw(is_undef is_string);
 use String::ShellQuote 1.01 qw(shell_quote);
 use utf8 ();
 
-our $VERSION = "0.005";
+our $VERSION = "0.006";
 
 sub _init_ftp($$) {
 	my($self, $hostname) = @_;
@@ -729,7 +729,8 @@ sub data_files {
 		$self->_ensure_standard_zonenames;
 		$self->_ensure_unpacked;
 		my $list = filter("", "cd @{[shell_quote($self->dir)]} && ".
-					"make zonenames AWK=echo");
+					"make zonenames ".
+					"AWK=echo VERSION_DEPS=");
 		$list =~ s#\A.*\{.*\} ##s;
 		$list =~ s#\n\z##;
 		$self->{data_files} =
@@ -742,7 +743,8 @@ sub _ensure_zic_built {
 	my($self) = @_;
 	unless($self->{zic_built}) {
 		$self->_ensure_unpacked;
-		filter("", "cd @{[shell_quote($self->dir)]} && make zic");
+		filter("", "cd @{[shell_quote($self->dir)]} && ".
+				"make zic VERSION_DEPS=");
 		$self->{zic_built} = 1;
 	}
 }
@@ -818,7 +820,8 @@ sub zoneinfo_dir {
 	my $zidir = $self->dir."/zoneinfo_$type";
 	unless($self->{"zoneinfo_built_$type"}) {
 		filter("", "cd @{[shell_quote($self->unpacked_dir)]} && ".
-			"make ${type}_only TZDIR=@{[shell_quote($zidir)]}");
+			"make ${type}_only TZDIR=@{[shell_quote($zidir)]} ".
+			"VERSION_DEPS=");
 		my %expect_names = %{$self->all_names};
 		my $skiplen = length($zidir) + 1;
 		_foreach_nondir_under($zidir, sub {
